@@ -529,7 +529,7 @@
         <location filename="mainwindow.ui" line="1523"/>
         <location filename="ui_mainwindow.h" line="1074"/>
         <source>Display help </source>
-        <translation>Exibir a ajuda</translation>
+        <translation>Exibir ajuda</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="1526"/>
